Get GitHub contributions, which can then be ordered with order_authors().
Value
A data frame with username of contributor, number of added lines of code, deleted lines of code, and number of commits.
Examples
head(get_contributions("report"))
#> Error in resp_body_raw(resp): Can't retrieve empty body.