Order GitHub authors based on contributions (obtained from get_contributions()).
Value
A data frame with username of contributor, number of added lines of code, deleted lines of code, number of commits, and a total 'score' column representing the sum of the other columns.
Examples
x <- get_contributions("report")
#> Error in resp_body_raw(resp): Can't retrieve empty body.
order_authors(x)
#> Error: object 'x' not found